package com.sample;

import java.io.File;

import android.app.Activity;
import android.content.Intent;
import android.net.Uri;
import android.os.Bundle;
import android.util.Log;
import android.view.View;
import android.widget.Button;
import android.widget.EditText;

public class MainActivity extends Activity {
	
	private static final String TAG = MainActivity.class.getName();
	private static final int OPEN_FILE_REQUEST = 0;
	private static final int OPEN_FOLDER_REQUEST = 1;
	private static final int SAVE_FILE_REQUEST = 2;
	private static final int SAVE_FOLDER_REQUEST = 3;
	private static final int UNCOMPRESS_REQUEST = 4;
	
    public void onCreate(Bundle savedInstanceState) 
    {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.main);
                
        // Open file
        Button openFileButton = (Button) findViewById(R.id.button_open_file_id);
        openFileButton.setOnClickListener(new View.OnClickListener()
        {
			public void onClick(View v) 
			{
				Intent intent = new Intent();
				intent.setAction(Intent.ACTION_PICK);
				// Browse in the following folder.
				Uri startDir = Uri.fromFile(new File("/sdcard"));
				// Files and directories
				intent.setDataAndType(startDir, "vnd.android.cursor.dir/lysesoft.andexplorer.file");
				// Optional filtering on file extension.
				intent.putExtra("browser_filter_extension_whitelist", "*.jpg,*.mp3,*.zip");
				// Title
				intent.putExtra("explorer_title", "Open File...");
				// Optional colors
				intent.putExtra("browser_title_background_color", "440000AA");
				intent.putExtra("browser_title_foreground_color", "FFFFFFFF");
				intent.putExtra("browser_list_background_color", "66000000");
				// Optional font scale
				intent.putExtra("browser_list_fontscale", "120%");
				// Optional 0=simple list, 1 = list with filename and size, 2 = list with filename, size and date.
				intent.putExtra("browser_list_layout", "2");
				startActivityForResult(intent, OPEN_FILE_REQUEST);
			}
        });
        
        // Open folder
        Button openFolderButton = (Button) findViewById(R.id.button_open_folder_id);
        openFolderButton.setOnClickListener(new View.OnClickListener()
        {
			public void onClick(View v) 
			{
				Intent intent = new Intent();
				intent.setAction(Intent.ACTION_PICK);
				// Browse in the following folder.
				Uri startDir = Uri.fromFile(new File("/sdcard"));
				// Files and directories
				intent.setDataAndType(startDir, "vnd.android.cursor.dir/lysesoft.andexplorer.directory");
				// Title
				intent.putExtra("explorer_title", "Select Folder...");
				startActivityForResult(intent, OPEN_FOLDER_REQUEST);
			}
        });         

        // Save file
        Button saveFileButton = (Button) findViewById(R.id.button_save_file_id);
        saveFileButton.setOnClickListener(new View.OnClickListener()
        {
    		public void onClick(View v) 
    		{
    			Intent intent = new Intent();
    			intent.setAction(Intent.ACTION_PICK);
    			// Browse in the following folder.
    			Uri startDir = Uri.fromFile(new File("/sdcard"));
    			// Files and directories
    			intent.setDataAndType(startDir, "vnd.android.cursor.dir/lysesoft.andexplorer.file");
    			// Optional filtering on file extension.
    			intent.putExtra("browser_filter_extension_whitelist", "*.xml");
    			// Title
    			intent.putExtra("explorer_title", "Save As...");
    			// Optional colors
    			intent.putExtra("browser_list_background_color", "66000000");
    			// Enable bottom line with textfield for filename
    			intent.putExtra("browser_line", "enabled");
    			// Optional filename in textfield
    			intent.putExtra("browser_line_textfield", "yourfile.xml");
    			startActivityForResult(intent, SAVE_FILE_REQUEST);
    		}
        }); 
        
        // Save folder
        Button saveFolderButton = (Button) findViewById(R.id.button_save_folder_id);
        saveFolderButton.setOnClickListener(new View.OnClickListener()
        {
    		public void onClick(View v) 
    		{
    			Intent intent = new Intent();
    			intent.setAction(Intent.ACTION_PICK);
    			// Browse in the following folder.
    			Uri startDir = Uri.fromFile(new File("/sdcard"));
    			// Files and directories
    			intent.setDataAndType(startDir, "vnd.android.cursor.dir/lysesoft.andexplorer.directory");
    			// Title
    			intent.putExtra("explorer_title", "Save Folder...");
    			// Optional colors
    			intent.putExtra("browser_list_background_color", "66000000");
    			// Enable bottom line with textfield for filename
    			intent.putExtra("browser_line", "enabled");
    			// Optional filename in textfield
    			intent.putExtra("browser_line_textfield", "newdirectory");
    			startActivityForResult(intent, SAVE_FOLDER_REQUEST);
    		}
        });

        // Save folder
        Button uncompressButton = (Button) findViewById(R.id.button_uncompress_id);
        final EditText uncompressText = (EditText) findViewById(R.id.uncompress_textfield_id);
        uncompressText.setText("/sdcard/localfolder/file1.zip");
        uncompressButton.setOnClickListener(new View.OnClickListener()
        {
    		public void onClick(View v) 
    		{
    	        Intent intent = new Intent();
    	        intent.setAction(Intent.ACTION_VIEW);
    	        
    	        // Archive to uncompress
    	        Uri uri = Uri.fromFile(new File(uncompressText.getText().toString()));
    	        intent.setDataAndType(uri, "application/zip");

    			// Title
    	        intent.putExtra("archiver_title", "Uncompress into..."); 

    			startActivityForResult(intent, UNCOMPRESS_REQUEST);
    		}
        });
        
    }


	protected void onActivityResult(int requestCode, int resultCode, Intent intent) 
	{
		Log.i(TAG, "Result: "+resultCode+ " from request: "+requestCode);
		if (intent != null)
		{
	        if (requestCode == OPEN_FILE_REQUEST)
	        {
		        Uri uri = intent.getData();
		        if (uri != null)
		        {
		        	EditText openFileTextField = (EditText) findViewById(R.id.open_file_textfield_id);
		        	openFileTextField.setText(uri.toString());
		        }
	        }
	        else if (requestCode == OPEN_FOLDER_REQUEST)
	        {
		        Uri uri = intent.getData();
		        if (uri != null)
		        {
		        	EditText openFolderTextField = (EditText) findViewById(R.id.open_folder_textfield_id);
		        	openFolderTextField.setText(uri.toString());
		        }
	        }
	        else if (requestCode == SAVE_FILE_REQUEST)
	        {
		        Uri uri = intent.getData();
		        if (uri != null)
		        {
		        	EditText saveFileTextField = (EditText) findViewById(R.id.save_file_textfield_id);
		        	saveFileTextField.setText(uri.toString());
		        }
	        }
	        else if (requestCode == SAVE_FOLDER_REQUEST)
	        {
		        Uri uri = intent.getData();
		        if (uri != null)
		        {
		        	EditText saveFolderTextField = (EditText) findViewById(R.id.save_folder_textfield_id);
		        	saveFolderTextField.setText(uri.toString());
		        }
	        }	 
	        else if (requestCode == UNCOMPRESS_REQUEST)
	        {

	        }
		}
	}
}